@@ -85,6 +85,8 @@ const (
 	EXIT SegmentType = "exit"
 	// FLUTTER writes the flutter version
 	FLUTTER SegmentType = "flutter"
+	// FORTRAN writes the gfortran version
+	FORTRAN SegmentType = "fortran"
 	// FOSSIL writes the fossil status
 	FOSSIL SegmentType = "fossil"
 	// GCP writes the active GCP context
@@ -183,6 +185,8 @@ const (
 	STATUS SegmentType = "status"
 	// STRAVA is a sports activity tracker
 	STRAVA SegmentType = "strava"
+	// Svelte segment
+	SVELTE SegmentType = "svelte"
 	// Subversion segment
 	SVN SegmentType = "svn"
 	// SWIFT writes the active swift version
@@ -191,6 +195,8 @@ const (
 	SYSTEMINFO SegmentType = "sysinfo"
 	// TALOSCTL writes the talosctl context
 	TALOSCTL SegmentType = "talosctl"
+	// Tauri Segment
+	TAURI SegmentType = "tauri"
 	// TERRAFORM writes the terraform workspace we're currently in
 	TERRAFORM SegmentType = "terraform"
 	// TEXT writes a text
@@ -254,6 +260,7 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	ELIXIR:          func() SegmentWriter { return &segments.Elixir{} },
 	EXIT:            func() SegmentWriter { return &segments.Status{} },
 	FLUTTER:         func() SegmentWriter { return &segments.Flutter{} },
+	FORTRAN:         func() SegmentWriter { return &segments.Fortran{} },
 	FOSSIL:          func() SegmentWriter { return &segments.Fossil{} },
 	GCP:             func() SegmentWriter { return &segments.Gcp{} },
 	FIREBASE:        func() SegmentWriter { return &segments.Firebase{} },
@@ -303,10 +310,12 @@ var Segments = map[SegmentType]func() SegmentWriter{
 	SPOTIFY:         func() SegmentWriter { return &segments.Spotify{} },
 	STATUS:          func() SegmentWriter { return &segments.Status{} },
 	STRAVA:          func() SegmentWriter { return &segments.Strava{} },
+	SVELTE:          func() SegmentWriter { return &segments.Svelte{} },
 	SVN:             func() SegmentWriter { return &segments.Svn{} },
 	SWIFT:           func() SegmentWriter { return &segments.Swift{} },
 	SYSTEMINFO:      func() SegmentWriter { return &segments.SystemInfo{} },
 	TALOSCTL:        func() SegmentWriter { return &segments.TalosCTL{} },
+	TAURI:           func() SegmentWriter { return &segments.Tauri{} },
 	TERRAFORM:       func() SegmentWriter { return &segments.Terraform{} },
 	TEXT:            func() SegmentWriter { return &segments.Text{} },
 	TIME:            func() SegmentWriter { return &segments.Time{} },
