@@ -74,6 +74,11 @@ func (e *Engine) canWriteRightBlock(length int, rprompt bool) (int, bool) {
 
 	canWrite := availableSpace >= promptBreathingRoom
 
+	// reset the available space when we can't write so we can fill the line
+	if !canWrite {
+		availableSpace = consoleWidth - length
+	}
+
 	return availableSpace, canWrite
 }
 
@@ -110,22 +115,25 @@ func (e *Engine) pwd() {
 }
 
 func (e *Engine) getNewline() string {
+	newline := "\n"
+
 	if e.Plain || e.Env.Flags().Debug {
-		return "\n"
+		return newline
 	}
 
 	// Warp terminal will remove a newline character ('\n') from the prompt, so we hack it in.
 	// For Elvish on Windows, we do this to prevent cutting off a right-aligned block.
-	if e.isWarp() || (e.Env.Shell() == shell.ELVISH && e.Env.GOOS() == runtime.WINDOWS) {
+	// For Tcsh, we do this to prevent a newline character from being printed.
+	switch {
+	case e.isWarp():
+		fallthrough
+	case e.Env.Shell() == shell.ELVISH && e.Env.GOOS() == runtime.WINDOWS:
+		fallthrough
+	case e.Env.Shell() == shell.TCSH:
 		return terminal.LineBreak()
+	default:
+		return newline
 	}
-
-	// To avoid improper translations in Tcsh, we use an invisible word joiner character (U+2060) to separate a newline from possible preceding escape sequences.
-	if e.Env.Shell() == shell.TCSH {
-		return "\u2060\\n"
-	}
-
-	return "\n"
 }
 
 func (e *Engine) writeNewline() {
