@@ -29,12 +29,10 @@ func TestEnabledGitNotFound(t *testing.T) {
 	env.On("HasCommand", "git").Return(false)
 	env.On("GOOS").Return("")
 	env.On("IsWsl").Return(false)
-	g := &Git{
-		scm: scm{
-			env:   env,
-			props: properties.Map{},
-		},
-	}
+
+	g := &Git{}
+	g.Init(properties.Map{}, env)
+
 	assert.False(t, g.Enabled())
 }
 
@@ -56,12 +54,10 @@ func TestEnabledInWorkingDirectory(t *testing.T) {
 	env.On("Home").Return(poshHome)
 	env.On("Getenv", poshGitEnv).Return("")
 	env.On("DirMatchesOneOf", testify_.Anything, testify_.Anything).Return(false)
-	g := &Git{
-		scm: scm{
-			env:   env,
-			props: properties.Map{},
-		},
-	}
+
+	g := &Git{}
+	g.Init(properties.Map{}, env)
+
 	assert.True(t, g.Enabled())
 	assert.Equal(t, fileInfo.Path, g.workingDir)
 }
@@ -74,13 +70,13 @@ func TestResolveEmptyGitPath(t *testing.T) {
 func TestEnabledInWorktree(t *testing.T) {
 	cases := []struct {
 		Case                  string
-		ExpectedEnabled       bool
 		WorkingFolder         string
 		WorkingFolderAddon    string
 		WorkingFolderContent  string
 		ExpectedRealFolder    string
 		ExpectedWorkingFolder string
 		ExpectedRootFolder    string
+		ExpectedEnabled       bool
 	}{
 		{
 			Case:                  "worktree",
@@ -138,12 +134,10 @@ func TestEnabledInWorktree(t *testing.T) {
 		env.On("HasFilesInDir", tc.WorkingFolder, tc.WorkingFolderAddon).Return(true)
 		env.On("HasFilesInDir", tc.WorkingFolder, "HEAD").Return(true)
 		env.On("PathSeparator").Return(string(os.PathSeparator))
-		g := &Git{
-			scm: scm{
-				env:   env,
-				props: properties.Map{},
-			},
-		}
+
+		g := &Git{}
+		g.Init(properties.Map{}, env)
+
 		assert.Equal(t, tc.ExpectedEnabled, g.hasWorktree(fileInfo), tc.Case)
 		assert.Equal(t, tc.ExpectedWorkingFolder, g.workingDir, tc.Case)
 		assert.Equal(t, tc.ExpectedRealFolder, g.realDir, tc.Case)
@@ -156,12 +150,12 @@ func TestEnabledInBareRepo(t *testing.T) {
 		Case            string
 		HEAD            string
 		IsBare          string
-		FetchRemote     bool
 		Remote          string
 		RemoteURL       string
-		ExpectedEnabled bool
 		ExpectedHEAD    string
 		ExpectedRemote  string
+		FetchRemote     bool
+		ExpectedEnabled bool
 	}{
 		{
 			Case:            "Bare repo on main",
@@ -198,15 +192,15 @@ func TestEnabledInBareRepo(t *testing.T) {
 		env.On("FileContent", "/home/user/bare.git/HEAD").Return(tc.HEAD)
 		env.MockGitCommand(pwd, tc.Remote, "remote")
 		env.MockGitCommand(pwd, tc.RemoteURL, "remote", "get-url", tc.Remote)
-		g := &Git{
-			scm: scm{
-				env: env,
-				props: properties.Map{
-					FetchBareInfo:     true,
-					FetchUpstreamIcon: tc.FetchRemote,
-				},
-			},
+
+		props := properties.Map{
+			FetchBareInfo:     true,
+			FetchUpstreamIcon: tc.FetchRemote,
 		}
+
+		g := &Git{}
+		g.Init(props, env)
+
 		assert.Equal(t, g.Enabled(), tc.ExpectedEnabled, tc.Case)
 		assert.Equal(t, g.Ref, tc.ExpectedHEAD, tc.Case)
 		assert.Equal(t, g.UpstreamIcon, tc.ExpectedRemote, tc.Case)
@@ -221,32 +215,33 @@ func TestGetGitOutputForCommand(t *testing.T) {
 	env.On("IsWsl").Return(false)
 	env.On("RunCommand", "git", append(args, commandArgs...)).Return(want, nil)
 	env.On("GOOS").Return("unix")
+
 	g := &Git{
 		scm: scm{
-			env:     env,
-			props:   properties.Map{},
 			command: GITCOMMAND,
 		},
 	}
+	g.Init(properties.Map{}, env)
+
 	got := g.getGitCommandOutput(commandArgs...)
 	assert.Equal(t, want, got)
 }
 
 func TestSetGitHEADContextClean(t *testing.T) {
 	cases := []struct {
-		Case        string
+		Ours        string
 		Expected    string
 		Ref         string
-		RebaseMerge bool
-		RebaseApply bool
-		Merge       bool
-		CherryPick  bool
-		Revert      bool
-		Sequencer   bool
-		Ours        string
-		Theirs      string
-		Step        string
+		Case        string
 		Total       string
+		Step        string
+		Theirs      string
+		RebaseMerge bool
+		Sequencer   bool
+		Revert      bool
+		CherryPick  bool
+		Merge       bool
+		RebaseApply bool
 	}{
 		{Case: "detached on commit", Ref: DETACHED, Expected: "branch detached at commit 1234567"},
 		{Case: "not detached, clean", Ref: "main", Expected: "branch main"},
@@ -366,23 +361,25 @@ func TestSetGitHEADContextClean(t *testing.T) {
 		env.On("HasFilesInDir", "", "sequencer/todo").Return(tc.Sequencer)
 		env.On("FileContent", "/sequencer/todo").Return(tc.Theirs)
 
+		props := properties.Map{
+			BranchIcon:     "branch ",
+			CommitIcon:     "commit ",
+			RebaseIcon:     "rebase ",
+			MergeIcon:      "merge ",
+			CherryPickIcon: "pick ",
+			TagIcon:        "tag ",
+			RevertIcon:     "revert ",
+		}
+
 		g := &Git{
 			scm: scm{
-				env: env,
-				props: properties.Map{
-					BranchIcon:     "branch ",
-					CommitIcon:     "commit ",
-					RebaseIcon:     "rebase ",
-					MergeIcon:      "merge ",
-					CherryPickIcon: "pick ",
-					TagIcon:        "tag ",
-					RevertIcon:     "revert ",
-				},
 				command: GITCOMMAND,
 			},
 			ShortHash: "1234567",
 			Ref:       tc.Ref,
 		}
+		g.Init(props, env)
+
 		g.setGitHEADContext()
 		assert.Equal(t, tc.Expected, g.HEAD, tc.Case)
 	}
@@ -409,18 +406,21 @@ func TestSetPrettyHEADName(t *testing.T) {
 		env.On("GOOS").Return("unix")
 		env.On("IsWsl").Return(false)
 		env.MockGitCommand("", tc.Tag, "describe", "--tags", "--exact-match")
+
+		props := properties.Map{
+			BranchIcon: "branch ",
+			CommitIcon: "commit ",
+			TagIcon:    "tag ",
+		}
+
 		g := &Git{
 			scm: scm{
-				env: env,
-				props: properties.Map{
-					BranchIcon: "branch ",
-					CommitIcon: "commit ",
-					TagIcon:    "tag ",
-				},
 				command: GITCOMMAND,
 			},
 			ShortHash: tc.ShortHash,
 		}
+		g.Init(props, env)
+
 		g.setPrettyHEADName()
 		assert.Equal(t, tc.Expected, g.HEAD, tc.Case)
 	}
@@ -428,16 +428,16 @@ func TestSetPrettyHEADName(t *testing.T) {
 
 func TestSetGitStatus(t *testing.T) {
 	cases := []struct {
-		Case                 string
-		Output               string
 		ExpectedWorking      *GitStatus
 		ExpectedStaging      *GitStatus
+		Case                 string
+		Output               string
 		ExpectedHash         string
 		ExpectedRef          string
 		ExpectedUpstream     string
-		ExpectedUpstreamGone bool
 		ExpectedAhead        int
 		ExpectedBehind       int
+		ExpectedUpstreamGone bool
 		Rebase               bool
 		Merge                bool
 	}{
@@ -579,13 +579,14 @@ func TestSetGitStatus(t *testing.T) {
 		env.On("GOOS").Return("unix")
 		env.On("IsWsl").Return(false)
 		env.MockGitCommand("", strings.ReplaceAll(tc.Output, "\t", ""), "status", "-unormal", "--branch", "--porcelain=2")
+
 		g := &Git{
 			scm: scm{
-				env:     env,
-				props:   properties.Map{},
 				command: GITCOMMAND,
 			},
 		}
+		g.Init(properties.Map{}, env)
+
 		if tc.ExpectedWorking == nil {
 			tc.ExpectedWorking = &GitStatus{}
 		}
@@ -610,8 +611,8 @@ func TestSetGitStatus(t *testing.T) {
 
 func TestGetStashContextZeroEntries(t *testing.T) {
 	cases := []struct {
-		Expected     int
 		StashContent string
+		Expected     int
 	}{
 		{Expected: 0, StashContent: ""},
 		{Expected: 2, StashContent: "1\n2\n"},
@@ -620,12 +621,14 @@ func TestGetStashContextZeroEntries(t *testing.T) {
 	for _, tc := range cases {
 		env := new(mock.Environment)
 		env.On("FileContent", "/logs/refs/stash").Return(tc.StashContent)
+
 		g := &Git{
 			scm: scm{
-				env:        env,
 				workingDir: "",
 			},
 		}
+		g.Init(properties.Map{}, env)
+
 		got := g.StashCount()
 		assert.Equal(t, tc.Expected, got)
 	}
@@ -697,14 +700,15 @@ func TestGitUpstream(t *testing.T) {
 				"src.example.com": "EX",
 			},
 		}
+
 		g := &Git{
 			scm: scm{
-				env:     env,
-				props:   props,
 				command: GITCOMMAND,
 			},
 			Upstream: "origin/main",
 		}
+		g.Init(props, env)
+
 		upstreamIcon := g.getUpstreamIcon()
 		assert.Equal(t, tc.Expected, upstreamIcon, tc.Case)
 	}
@@ -714,9 +718,9 @@ func TestGetBranchStatus(t *testing.T) {
 	cases := []struct {
 		Case         string
 		Expected     string
+		Upstream     string
 		Ahead        int
 		Behind       int
-		Upstream     string
 		UpstreamGone bool
 	}{
 		{Case: "Equal with remote", Expected: "equal", Upstream: branchName},
@@ -735,15 +739,15 @@ func TestGetBranchStatus(t *testing.T) {
 			BranchIdenticalIcon: "equal",
 			BranchGoneIcon:      "gone",
 		}
+
 		g := &Git{
-			scm: scm{
-				props: props,
-			},
 			Ahead:        tc.Ahead,
 			Behind:       tc.Behind,
 			Upstream:     tc.Upstream,
 			UpstreamGone: tc.UpstreamGone,
 		}
+		g.Init(props, new(mock.Environment))
+
 		g.setBranchStatus()
 		assert.Equal(t, tc.Expected, g.BranchStatus, tc.Case)
 	}
@@ -751,10 +755,10 @@ func TestGetBranchStatus(t *testing.T) {
 
 func TestGitTemplateString(t *testing.T) {
 	cases := []struct {
+		Git      *Git
 		Case     string
 		Expected string
 		Template string
-		Git      *Git
 	}{
 		{
 			Case:     "Only HEAD name",
@@ -886,9 +890,9 @@ func TestGitTemplateString(t *testing.T) {
 
 func TestGitUntrackedMode(t *testing.T) {
 	cases := []struct {
+		UntrackedModes map[string]string
 		Case           string
 		Expected       string
-		UntrackedModes map[string]string
 	}{
 		{
 			Case:     "Default mode - no map",
@@ -919,14 +923,17 @@ func TestGitUntrackedMode(t *testing.T) {
 	}
 
 	for _, tc := range cases {
+		props := properties.Map{
+			UntrackedModes: tc.UntrackedModes,
+		}
+
 		g := &Git{
 			scm: scm{
-				props: properties.Map{
-					UntrackedModes: tc.UntrackedModes,
-				},
 				realDir: "foo",
 			},
 		}
+		g.Init(props, new(mock.Environment))
+
 		got := g.getUntrackedFilesMode()
 		assert.Equal(t, tc.Expected, got, tc.Case)
 	}
@@ -934,9 +941,9 @@ func TestGitUntrackedMode(t *testing.T) {
 
 func TestGitIgnoreSubmodules(t *testing.T) {
 	cases := []struct {
+		IgnoreSubmodules map[string]string
 		Case             string
 		Expected         string
-		IgnoreSubmodules map[string]string
 	}{
 		{
 			Case:     "Overide",
@@ -961,14 +968,17 @@ func TestGitIgnoreSubmodules(t *testing.T) {
 	}
 
 	for _, tc := range cases {
+		props := properties.Map{
+			IgnoreSubmodules: tc.IgnoreSubmodules,
+		}
+
 		g := &Git{
 			scm: scm{
-				props: properties.Map{
-					IgnoreSubmodules: tc.IgnoreSubmodules,
-				},
 				realDir: "foo",
 			},
 		}
+		g.Init(props, new(mock.Environment))
+
 		got := g.getIgnoreSubmodulesMode()
 		assert.Equal(t, tc.Expected, got, tc.Case)
 	}
@@ -1093,12 +1103,14 @@ func TestGitCommit(t *testing.T) {
 	for _, tc := range cases {
 		env := new(mock.Environment)
 		env.MockGitCommand("", tc.Output, "log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H%nrf:%D", "--decorate=full")
+
 		g := &Git{
 			scm: scm{
-				env:     env,
-				command: "git",
+				command: GITCOMMAND,
 			},
 		}
+		g.Init(properties.Map{}, env)
+
 		got := g.Commit()
 		assert.Equal(t, tc.Expected, got, tc.Case)
 	}
@@ -1107,8 +1119,8 @@ func TestGitCommit(t *testing.T) {
 func TestGitRemotes(t *testing.T) {
 	cases := []struct {
 		Case     string
-		Expected int
 		Config   string
+		Expected int
 	}{
 		{
 			Case:     "Empty config file",
@@ -1148,11 +1160,10 @@ func TestGitRemotes(t *testing.T) {
 
 		g := &Git{
 			scm: scm{
-				props:   properties.Map{},
 				realDir: "foo",
-				env:     env,
 			},
 		}
+		g.Init(properties.Map{}, env)
 
 		got := g.Remotes()
 		assert.Equal(t, tc.Expected, len(got), tc.Case)
@@ -1194,13 +1205,12 @@ func TestGitRepoName(t *testing.T) {
 
 		g := &Git{
 			scm: scm{
-				props:      properties.Map{},
-				env:        env,
 				realDir:    tc.RealDir,
 				workingDir: tc.WorkingDir,
 			},
 			IsWorkTree: tc.IsWorkTree,
 		}
+		g.Init(properties.Map{}, env)
 
 		got := g.repoName()
 		assert.Equal(t, tc.Expected, got, tc.Case)
