@@ -1,20 +1,15 @@
 package segments
 
 import (
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Session struct {
-	props properties.Properties
-	env   runtime.Environment
-	// text  string
+	base
 
-	SSHSession bool
-
-	// Deprecated
 	DefaultUserName string
+	SSHSession      bool
 }
 
 func (s *Session) Enabled() bool {
@@ -26,11 +21,6 @@ func (s *Session) Template() string {
 	return " {{ if .SSHSession }}\ueba9 {{ end }}{{ .UserName }}@{{ .HostName }} "
 }
 
-func (s *Session) Init(props properties.Properties, env runtime.Environment) {
-	s.props = props
-	s.env = env
-}
-
 func (s *Session) activeSSHSession() bool {
 	keys := []string{
 		"SSH_CONNECTION",
