@@ -17,13 +17,13 @@ import (
 
 func TestUpgrade(t *testing.T) {
 	cases := []struct {
+		Error           error
 		Case            string
-		ExpectedEnabled bool
-		HasCache        bool
 		CurrentVersion  string
 		LatestVersion   string
 		CachedVersion   string
-		Error           error
+		ExpectedEnabled bool
+		HasCache        bool
 	}{
 		{
 			Case:            "Should upgrade",
@@ -82,10 +82,8 @@ func TestUpgrade(t *testing.T) {
 		json := fmt.Sprintf(`{"tag_name":"v%s"}`, tc.LatestVersion)
 		env.On("HTTPRequest", upgrade.RELEASEURL).Return([]byte(json), tc.Error)
 
-		ug := &Upgrade{
-			env:   env,
-			props: properties.Map{},
-		}
+		ug := &Upgrade{}
+		ug.Init(properties.Map{}, env)
 
 		enabled := ug.Enabled()
 
